This is a python package that tries to give its users time complexity of any function you desire. There are limitations to this
library, which will are still working on. 
Currently the types of functions for which the library works is:
1. Single Variable input functions
2. Non-recursive functions
3. In-built library support is not available at the moment
